Coverage report

# Coverage report: 34%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 4665 | 3098 | 0 | 34%
appr/__init__.py | 3 | 0 | 0 | 100%
appr/api/__init__.py | 0 | 0 | 0 | 100%
appr/api/app.py | 35 | 25 | 0 | 29%
appr/api/builder.py | 32 | 32 | 0 | 0%
appr/api/config.py | 11 | 0 | 0 | 100%
appr/api/deployment.py | 30 | 30 | 0 | 0%
appr/api/gevent_app.py | 12 | 5 | 0 | 58%
appr/api/gunicorn_app.py | 18 | 18 | 0 | 0%
appr/api/impl/__init__.py | 0 | 0 | 0 | 100%
appr/api/impl/builder.py | 12 | 12 | 0 | 0%
appr/api/impl/registry.py | 56 | 56 | 0 | 0%
appr/api/info.py | 31 | 31 | 0 | 0%
appr/api/registry.py | 117 | 117 | 0 | 0%
appr/api/wsgi.py | 3 | 3 | 0 | 0%
appr/auth.py | 77 | 7 | 0 | 91%
appr/client.py | 176 | 138 | 0 | 22%
appr/commands/__init__.py | 0 | 0 | 0 | 100%
appr/commands/channel.py | 48 | 37 | 0 | 23%
appr/commands/cli.py | 47 | 24 | 0 | 49%
appr/commands/command_base.py | 166 | 113 | 0 | 32%
appr/commands/config.py | 29 | 15 | 0 | 48%
appr/commands/delete_package.py | 28 | 17 | 0 | 39%
appr/commands/deploy.py | 46 | 32 | 0 | 30%
appr/commands/generate.py | 19 | 19 | 0 | 0%
appr/commands/helm.py | 75 | 46 | 0 | 39%
appr/commands/inspect.py | 41 | 29 | 0 | 29%
appr/commands/jsonnet.py | 35 | 22 | 0 | 37%
appr/commands/list_package.py | 41 | 28 | 0 | 32%
appr/commands/login.py | 57 | 44 | 0 | 23%
appr/commands/logout.py | 31 | 20 | 0 | 35%
appr/commands/plugins.py | 60 | 38 | 0 | 37%
appr/commands/pull.py | 43 | 31 | 0 | 28%
appr/commands/push.py | 116 | 90 | 0 | 22%
appr/commands/remove.py | 6 | 6 | 0 | 0%
appr/commands/runserver.py | 21 | 9 | 0 | 57%
appr/commands/show.py | 32 | 19 | 0 | 41%
appr/commands/version.py | 35 | 20 | 0 | 43%
appr/config.py | 36 | 23 | 0 | 36%
appr/discovery.py | 51 | 39 | 0 | 24%
appr/display.py | 34 | 15 | 0 | 56%
appr/exception.py | 62 | 10 | 0 | 84%
appr/formats/__init__.py | 0 | 0 | 0 | 100%
appr/formats/appr/__init__.py | 0 | 0 | 0 | 100%
appr/formats/appr/kpm.py | 8 | 1 | 0 | 88%
appr/formats/appr/kub.py | 119 | 89 | 0 | 25%
appr/formats/appr/kub_base.py | 122 | 87 | 0 | 29%
appr/formats/appr/kubplain.py | 19 | 8 | 0 | 58%
appr/formats/appr/manifest.py | 30 | 9 | 0 | 70%
appr/formats/appr/manifest_jsonnet.py | 52 | 15 | 0 | 71%
appr/formats/base.py | 67 | 39 | 0 | 42%
appr/formats/helm/__init__.py | 0 | 0 | 0 | 100%
appr/formats/helm/chart.py | 52 | 32 | 0 | 38%
appr/formats/helm/manifest_chart.py | 48 | 29 | 0 | 40%
appr/formats/utils.py | 22 | 11 | 0 | 50%
appr/models/__init__.py | 24 | 6 | 0 | 75%
appr/models/blob_base.py | 24 | 11 | 0 | 54%
appr/models/channel_base.py | 48 | 27 | 0 | 44%
appr/models/db_base.py | 48 | 31 | 0 | 35%
appr/models/kv/__init__.py | 2 | 0 | 0 | 100%
appr/models/kv/blob_kv_base.py | 13 | 4 | 0 | 69%
appr/models/kv/channel_kv_base.py | 36 | 21 | 0 | 42%
appr/models/kv/etcd/__init__.py | 6 | 0 | 0 | 100%
appr/models/kv/etcd/blob.py | 5 | 0 | 0 | 100%
appr/models/kv/etcd/channel.py | 5 | 0 | 0 | 100%
appr/models/kv/etcd/db.py | 23 | 6 | 0 | 74%
appr/models/kv/etcd/models_index.py | 39 | 25 | 0 | 36%
appr/models/kv/etcd/package.py | 5 | 0 | 0 | 100%
appr/models/kv/filesystem/__init__.py | 49 | 34 | 0 | 31%
appr/models/kv/filesystem/blob.py | 5 | 0 | 0 | 100%
appr/models/kv/filesystem/channel.py | 5 | 0 | 0 | 100%
appr/models/kv/filesystem/db.py | 19 | 3 | 0 | 84%
appr/models/kv/filesystem/models_index.py | 33 | 20 | 0 | 39%
appr/models/kv/filesystem/package.py | 5 | 0 | 0 | 100%
appr/models/kv/models_index_base.py | 264 | 214 | 0 | 19%
appr/models/kv/package_kv_base.py | 69 | 47 | 0 | 32%
appr/models/kv/redis/__init__.py | 4 | 0 | 0 | 100%
appr/models/kv/redis/blob.py | 5 | 0 | 0 | 100%
appr/models/kv/redis/channel.py | 5 | 0 | 0 | 100%
appr/models/kv/redis/db.py | 18 | 3 | 0 | 83%
appr/models/kv/redis/models_index.py | 33 | 20 | 0 | 39%
appr/models/kv/redis/package.py | 5 | 0 | 0 | 100%
appr/models/package_base.py | 168 | 116 | 0 | 31%
appr/pack.py | 115 | 77 | 0 | 33%
appr/platforms/__init__.py | 0 | 0 | 0 | 100%
appr/platforms/dockercompose.py | 25 | 25 | 0 | 0%
appr/platforms/helm.py | 12 | 12 | 0 | 0%
appr/platforms/kubernetes.py | 146 | 119 | 0 | 18%
appr/plugins/__init__.py | 0 | 0 | 0 | 100%
appr/plugins/helm.py | 62 | 46 | 0 | 26%
appr/render_jsonnet.py | 75 | 21 | 0 | 72%
appr/semver.py | 17 | 12 | 0 | 29%
appr/template_filters.py | 118 | 79 | 0 | 33%
appr/tests/__init__.py | 0 | 0 | 0 | 100%
appr/tests/conftest.py | 101 | 58 | 0 | 43%
appr/tests/test_apiserver.py | 349 | 266 | 0 | 24%
appr/tests/test_models.py | 221 | 169 | 0 | 24%
appr/utils.py | 148 | 86 | 0 | 42%

No items found using the specified filter.